SNIC UART Interface library: Serial to Wi-Fi library for Murata TypeYD Wi-Fi module. For more information about TypeYD: http://www.murata.co.jp/products/microwave/module/lbwb1zzydz/index.html

Dependents:   SNIC-xively-jumpstart-demo SNIC-FluentLogger-example TCPEchoServer murataDemo ... more

Fork of YDwifiInterface by Takao Kishino

Revision:
53:b53ccb9989c4
Parent:
51:69a9cf901d54
--- a/SNIC_WifiInterface.h	Tue Mar 31 03:12:35 2015 +0000
+++ b/SNIC_WifiInterface.h	Tue Mar 31 03:16:46 2015 +0000
@@ -38,6 +38,10 @@
 class C_SNIC_WifiInterface : public C_MurataObject {
 
 public:
+    /** Default constructor
+    */
+    C_SNIC_WifiInterface() {};
+    
     /** Constructor
         @param tx mbed pin to use for tx line of Serial interface
         @param rx mbed pin to use for rx line of Serial interface
@@ -50,7 +54,11 @@
     C_SNIC_WifiInterface(PinName tx, PinName rx, PinName cts, PinName rts, PinName reset, PinName alarm = NC, int baud = 115200);
     virtual ~C_SNIC_WifiInterface();
 
-    /** Initialize the interface.
+    /** Create instance.
+    */
+    void create(PinName tx, PinName rx, PinName cts, PinName rts, PinName reset, PinName alarm = NC, int baud = 115200);
+
+     /** Initialize the interface.
         @return 0 on success, a negative number on failure
     */
     int init();